@@ -29,7 +29,7 @@ our @EXPORT = qw( array_to_moose
 
 );
 
-use version; our $VERSION = qv('0.0.8');
+use version; our $VERSION = qv('0.0.9');
 
 # BEGIN { $Exporter::Verbose=1 };
 
@@ -459,7 +459,7 @@ sub _check_subobj {
   BEGIN
   {
     %simple_types = map { $_ => 1 }
-      qw ( Any Item Bool Undef Defined Value Str Num Int );
+      qw ( Any Item Bool Undef Defined Value Str Num Int __ANON__ );
   }
 
 ########################################
@@ -562,7 +562,7 @@ Array::To::Moose - Build Moose objects from a data array
 
 =head1 VERSION
 
-This document describes Array::To::Moose version 0.0.8
+This document describes Array::To::Moose version 0.0.9
 
 =head1 SYNOPSIS
 
